/*
 * Represents a word and associate data about the word such as its count and timestamp.
 * Needed since we don't always have the location in the trie as context to tell use the
 * actual string of the word in the trie.
 * 
 * Author(s): Keith Vertanen
 */

import java.util.Comparator;

public class WordData
{
    private String word;
    private VocabData data;

    public WordData(String word, VocabData data)
    {
        this.word = word;
        this.data = data;
    }
    
    public String getWord()
    {
        return word;
    }
    
    public VocabData getData()
    {
        return data;
    }
    
    // Sorts WordData objects in descending order of the used counts
    static public class CountComparator implements Comparator<WordData>
    {
        @Override
        public int compare(WordData o1, WordData o2)
        {
            if (o1.data.getUsedCount() < o2.data.getUsedCount())
                return 1;
            else if (o1.data.getUsedCount() > o2.data.getUsedCount())
                return -1;
            else
                return 0;
        }
    }
    
    // Sorts WordData objects so most recently used appears first in the list
    static public class TimeComparator implements Comparator<WordData>
    {
        @Override
        public int compare(WordData o1, WordData o2)
        {
            if (o1.data.getLastUsedTimestamp() < o2.data.getLastUsedTimestamp())
                return 1;
            else if (o1.data.getLastUsedTimestamp() > o2.data.getLastUsedTimestamp())
                return -1;
            else
                return 0;
        }
    }
    
}
     